Re: [PATCH] f2fs: fix typos in code comments

2019-01-25 Thread Chao Yu
On 2019/1/25 15:35, Geliang Tang wrote:
> lengh -> length
> 
> Signed-off-by: Geliang Tang 

Reviewed-by: Chao Yu 

Thanks,



[PATCH] f2fs: fix typos in code comments

2019-01-24 Thread Geliang Tang
lengh -> length

Signed-off-by: Geliang Tang 
---
 include/linux/f2fs_fs.h | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/include/linux/f2fs_fs.h b/include/linux/f2fs_fs.h
index d7711048ef93..624b8a47d3c6 100644
--- a/include/linux/f2fs_fs.h
+++ b/include/linux/f2fs_fs.h
@@ -186,7 +186,7 @@ struct f2fs_orphan_block {
 struct f2fs_extent {
__le32 fofs;/* start file offset of the extent */
__le32 blk; /* start block address of the extent */
-   __le32 len; /* lengh of the extent */
+   __le32 len; /* length of the extent */
 } __packed;
 
 #define F2FS_NAME_LEN  255
@@ -511,7 +511,7 @@ typedef __le32  f2fs_hash_t;
 struct f2fs_dir_entry {
__le32 hash_code;   /* hash code of file name */
__le32 ino; /* inode number */
-   __le16 name_len;/* lengh of file name */
+   __le16 name_len;/* length of file name */
__u8 file_type; /* file type */
 } __packed;
 
-- 
2.17.1